@echo off
setlocal

@rem *** path to the signing scripts
set SIGNDIR=..\signing

@rem *** path to the setup files
set SETUPDIR=.

@rem *** driver package folder
set DRVPCK_DBG_X86=..\drvpackage_x86_dbg
set DRVPCK_DBG_X64=..\drvpackage_x64_dbg
set DRVPCK_REL_X86=..\drvpackage_x86
set DRVPCK_REL_X64=..\drvpackage_x64

@rem *** setup package folder
set TGTDIR_DBG=.\_disk_debug
set TGTDIR_REL=.\_disk
set TGTSUBDIR_X86=x86
set TGTSUBDIR_X64=x64
:subdir_end

@rem delete setup package folder
rmdir /S /Q %TGTDIR_DBG% >nul 2>nul
rmdir /S /Q %TGTDIR_REL% >nul 2>nul

@rem create setup package folder
mkdir %TGTDIR_DBG%\%TGTSUBDIR_X86% >nul 2>nul
mkdir %TGTDIR_DBG%\%TGTSUBDIR_X64% >nul 2>nul
mkdir %TGTDIR_REL%\%TGTSUBDIR_X86% >nul 2>nul
mkdir %TGTDIR_REL%\%TGTSUBDIR_X64% >nul 2>nul

@rem *** NOTE: We should always use the full list of OS.

@rem *** OS list for x86
set OSLIST_x86=2000,XP_X86,Server2003_X86,Vista_X86,7_X86,Server2008_X86,8_X86
@rem *** OS list for x64
set OSLIST_x64=XP_X64,Server2003_X64,Vista_X64,7_X64,Server2008_X64,Server2008R2_X64,8_X64,Server8_X64

@rem
@rem OS list contains a combination of the following values:
@rem    2000  XP_X86   Server2003_X86   Vista_X86  7_X86  Server2008_X86					  8_X86
@rem          XP_X64   Server2003_X64   Vista_X64  7_X64  Server2008_X64   Server2008R2_X64   8_X64  Server8_X64
@rem                   Server2003_IA64                    Server2008_IA64  Server2008R2_IA64    
@rem                                                                                          8_ARM
@rem                                                                                  


@rem set signing variables
call "%SIGNDIR%\set_sign_tools.cmd"
if not "%errorlevel%"=="0" goto end

@rem sign the driver packages and add them to the corresponding setup packages
@call :AddSignedDrvPckToSetup %DRVPCK_DBG_X86% %TGTDIR_DBG%\%TGTSUBDIR_X86% %OSLIST_x86%
@call :AddSignedDrvPckToSetup %DRVPCK_DBG_X64% %TGTDIR_DBG%\%TGTSUBDIR_X64% %OSLIST_x64%
@call :AddSignedDrvPckToSetup %DRVPCK_REL_X86% %TGTDIR_REL%\%TGTSUBDIR_X86% %OSLIST_x86%
@call :AddSignedDrvPckToSetup %DRVPCK_REL_X64% %TGTDIR_REL%\%TGTSUBDIR_X64% %OSLIST_x64%

@rem extract public certificate file from system store and add them to the setup packages
@echo.
@echo.
@echo *** Extracting public key from cert "%VENDOR_CERTIFICATE%"
@echo on
%SIGNTOOLS%\bin\certmgr.exe /put /c /s my /n "%VENDOR_CERTIFICATE%" %TGTDIR_DBG%\vendor.cer
@set RETCODE=%errorlevel%
@if not "%RETCODE%"=="0" (
  @pause
  @goto end
)
copy %TGTDIR_DBG%\vendor.cer %TGTDIR_REL%
@echo off

@rem copy the setup files to the setup packages
@copy %SETUPDIR%\setup.exe %TGTDIR_DBG%
@copy %SETUPDIR%\setup.ini %TGTDIR_DBG%
@copy %SETUPDIR%\setup.exe %TGTDIR_REL%
@copy %SETUPDIR%\setup.ini %TGTDIR_REL%
@if exist "%SETUPDIR%\RunSetup.exe" (
  @copy %SETUPDIR%\RunSetup.exe %TGTDIR_DBG%
  @copy %SETUPDIR%\RunSetup.exe %TGTDIR_REL%
)
@if exist "%SETUPDIR%\autorun.inf" (
  @copy %SETUPDIR%\autorun.inf %TGTDIR_DBG%
  @copy %SETUPDIR%\autorun.inf %TGTDIR_REL%
)


@rem sign the setup executables
@echo.
@echo.
@echo *** Signing setup applications
@echo on
cmd /c %SIGNDIR%\vendor_sign_files.cmd %TGTDIR_REL%\setup.exe %TGTDIR_DBG%\setup.exe
@if exist "%SETUPDIR%\RunSetup.exe" (
  cmd /c %SIGNDIR%\vendor_sign_files.cmd %TGTDIR_REL%\RunSetup.exe %TGTDIR_DBG%\RunSetup.exe
)
@echo off

goto end
rem *************** end of 'main'

rem *************** procedures begin here ****************************

rem *** AddSignedDrvPckToSetup %1=DrvPckDir %2=SetupPckDir %3=OSListForCat
:AddSignedDrvPckToSetup

@rem copy the driver package to a temporary folder
@set TMPDIR=.\tmp_drvpck
@rmdir /S /Q %TMPDIR% >nul 2>nul
@mkdir %TMPDIR% >nul 2>nul
@copy %1\*.* %TMPDIR%

@rem sign the .sys files of the driver package
@echo.
@echo.
@echo *** Signing .sys Files
@echo on
cmd /c %SIGNDIR%\vendor_sign_files.cmd %TMPDIR%\*.sys
@echo off

@rem create .cat files
@echo.
@echo.
@echo *** Creating .cat Files
@echo on
%SIGNTOOLS%\bin\inf2cat.exe /driver:%TMPDIR%  /os:%3
@set RETCODE=%errorlevel%
@echo off
if not "%RETCODE%"=="0" (
  pause
  goto cleanup
)

@rem sign .cat files
@echo.
@echo.
@echo *** Signing .cat Files
@echo on
cmd /c %SIGNDIR%\vendor_sign_files.cmd %TMPDIR%\*.cat
@echo off

@rem copy the signed driver package to the setup package
@copy %TMPDIR%\*.* %2

@rem cleanup
:cleanup
@rmdir /S /Q %TMPDIR% >nul 2>nul

@exit /b 0
rem ***

rem *************** procedures end here ******************************

:end
endlocal

rem *** EOF ***